Re-exports
pub use git::CheckoutOptions;pub use git::LfsFilter;
Modules
Structs
- GitUrl
- A URL reference to a Git repository.
- Lazy
Client - Initialization of the reqwest client can be expensive, using this struct allows creating the client only when needed.
Enums
Constants
- GIT_
SSH_ CLONING_ WARNING_ MSG - The warning message used in reporter for SSH cloning. This is intended to help user understand that they need to set their SSH passphrase before cloning a repository using SSH, otherwise the process can hang. Original issue: https://github.com/prefix-dev/pixi/issues/3709
- GIT_
URL_ QUERY_ REV_ TYPE - The query parameter used to specify the type of reference in a Git URL.